package com.gxzc.zen.common.config.json

import com.fasterxml.jackson.databind.ObjectMapper
import com.gxzc.zen.common.config.json.annotation.ZenJsonFilter
import kotlin.reflect.KClass

/**
 * 自定义的Json序列化工具类
 * @author NorthLan
 * @date 2018/3/12
 * @url https://noahlan.com
 */
class ZenJsonSerializer {
    private val mapper = ObjectMapper()
    private val jacksonFilter = ZenJacksonJsonFilter()

    fun filter(clazz: KClass<*>?, include: Array<String>?, filter: Array<String>?) {
        if (clazz == null) {
            return
        }
        if (include != null && include.isNotEmpty()) {
            jacksonFilter.include(clazz, include)
        }
        if (filter != null && filter.isNotEmpty()) {
            jacksonFilter.filter(clazz, filter)
        }
        mapper.addMixIn(clazz.java, jacksonFilter::class.java)
    }

    fun toJson(any: Any): String {
        mapper.setFilterProvider(jacksonFilter)
        return mapper.writeValueAsString(any)
    }

    fun filter(zenJsonFilter: ZenJsonFilter) {
        this.filter(zenJsonFilter.type, zenJsonFilter.include, zenJsonFilter.filter)
    }
}